Combination
===========

.. currentmodule:: pykeen.nn.combinations

.. autoclass:: Combination
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Combination.forward

   .. rubric:: Methods Documentation

   .. automethod:: forward
